#include "cctk.h"
#include "cctk_Parameters.h"
#include "cctk_Arguments.h"

#include <cstdio>
#include <cerrno>
#include <cstring>

#include <vector>

extern "C"
void ReadSphericalStar_Read(CCTK_ARGUMENTS)
{
  DECLARE_CCTK_PARAMETERS;
  DECLARE_CCTK_ARGUMENTS;

  // open file here "filename" is a char* with the name
  // you can define new parameters in the file param.ccl
  std::vector<double> radii, densities;
  double rad, dens;
  FILE *fh = fopen(filename, "r");
  if(fh == NULL)
    CCTK_VError(__LINE__, __FILE__, CCTK_THORNSTRING,
                "Could not open file '%s' for reading: %s",
                filename, strerror(errno));
  while(fscanf(fh, "%lg %lg\n", &rad, &dens)) {
    radii.push_back(rad);
    densities.push_back(dens);
  }
  fclose(fh);

  for(int k = 0 ; k < cctk_lsh[2] ; k++) {
    for(int j = 0 ; j < cctk_lsh[1] ; j++) {
      for(int i = 0 ; i < cctk_lsh[0] ; i++) {
        const int idx = CCTK_GFINDEX3D(cctkGH, i,j,k);
        const CCTK_REAL xL = x[idx];
        const CCTK_REAL yL = y[idx];
        const CCTK_REAL zL = z[idx];

        // interpolate your data to point with Cartesian, isotropic coordinates
        // xL,yL,zL

        rho[idx] = 0; // rest mass density
        press[idx] = 0; // pressure
        eps[idx] = 0; // specific internal energy
        // three velocity
        vel[CCTK_VECTGFINDEX3D(cctkGH, i,j,k, 0)] = 0.;
        vel[CCTK_VECTGFINDEX3D(cctkGH, i,j,k, 1)] = 0.;
        vel[CCTK_VECTGFINDEX3D(cctkGH, i,j,k, 2)] = 0.;

        alp[idx] = 1.; // lapse
        betax[idx] = 1.; // shift vector x-component
        betay[idx] = 0.; // shift vector y-component
        betaz[idx] = 0.; // shift vector z-component

        gxx[idx] = 1.; // g_{xx} if spatial metric
        gyy[idx] = 1.; // g_{yy} if spatial metric
        gzz[idx] = 1.; // g_{zz} if spatial metric
        gxy[idx] = 0.; // g_{xy} if spatial metric
        gxz[idx] = 0.; // g_{xz} if spatial metric
        gyz[idx] = 0.; // g_{yz} if spatial metric
      }
    }
  }

}
